<h1>Tiquations 1.1</h1>

<h2>Welcome</h2>
<p>Tiquations is an Open-Source Python package that is aimed at giving mathematicians and scientists easy access to important equations that they may use often. It was made in python 3.7 and should work on all versions higher than 3.0.</p>
<h2>Documentation</h2>
<p>I have created a website using wix but it's really not that great. The easiest way to go about reading documentation is to type tiquations.help() in your console.</p>

<h2>Help commands</h2>
<ul>
<li>tiquations.help()</li>
<li>constants.variables()</li>
<li>tiquations.version()</li>
</ul>

<h2>Equations</h2>
<ul>
<li>Quadratic equation</li>
<li>Mathematical sequence equations</li>
<li>Cosine Rules for angles and sides</li>
<li>Distance/Speed/Time</li>
<li>Force/Mass/Acceleration</li>
<li>Weight/Mass/Gravitational field strength</li>
<li>Circle area/diameter/circumference</li>
<li>Delta Velocity/Time taken/Acceleration</li>
<li>Force/Area/Pressure</li>
<li>Cylinder Volume/Surface Area</li>
<li>Trapezoid Area/Height/Surface Area</li>
<li>Pythagoras' Theorum</li>
<li>Energy/Charge/Potential difference</li>
<li>Power/Current/Potential difference</li>
<li>Power/Energy/Time</li>
<li>Orbital speed/Radius/Time taken</li>
</ul>
